@@ -21,7 +21,7 @@
 
 default_config="/etc/clamav-unofficial-sigs.conf"
 
-version="v3.6 (updated 2009-08-23)"
+version="v3.7.1 (updated 2010-06-06)"
 output_ver="
    `basename $0` $version
 "
@@ -124,7 +124,7 @@ while getopts 'bc:defg:himrs:tv' option ; do
                             echo "$file_sig" | tr -d "\r" >> "$config_dir/monitor-ign.txt"
                             if clamscan --quiet -d "$config_dir/local.ign" "$config_dir/scan-test.txt"
                                then
-                                  if rsync -cqt $config_dir/local.ign $clam_dbs
+                                  if rsync -pcqt $config_dir/local.ign $clam_dbs
                                      then
                                         perms chown $clam_user:$clam_group local.ign
                                         chmod 0644 local.ign "$config_dir/monitor-ign.txt"
@@ -307,11 +307,11 @@ while getopts 'bc:defg:himrs:tv' option ; do
 
             Example:
 
-               =:This signature{-10}contains several(5|6|7)formatted spacing*fields
+               =:This signature{-10}contains several(25|26|27)formatted spacing*fields
 
             Encodes to:
 
-            54686973207369676e6174757265{-10}636f6e7461696e73207365766572616c(5|6|7)666f726d61747465642073706163696e67*6669656c6473
+            54686973207369676e6174757265{-10}636f6e7461696e73207365766572616c(25|26|27)666f726d61747465642073706163696e67*6669656c6473
 
             Use 'full' encoding if you want to encode everything on the line [including {}, (), *] and 'formatted'
             encoding if you want to encode everything on the line except the formatted character spacing fields.
@@ -356,7 +356,7 @@ while getopts 'bc:defg:himrs:tv' option ; do
                             else
                                echo "$line" | perl -pe 's/(.)/sprintf("%02lx", ord $1)/eg' | sed "s/^/$prefix\.$line_num:4:\*:/" >> "$path_file"
                          fi
-                         echo -ne "Hexadecimal encoding $source_file line: $line_num of $total\r"
+                         printf "Hexadecimal encoding $source_file line: $line_num of $total\r"
                          line_num=$(($line_num + 1))
                       done
                    else
@@ -379,7 +379,7 @@ while getopts 'bc:defg:himrs:tv' option ; do
                          then
                             if ! cmp -s "$path_file" "$clam_dbs/$db_file"
                                then
-                                  if rsync -cqt "$path_file" "$clam_dbs"
+                                  if rsync -pcqt "$path_file" "$clam_dbs"
                                      then
                                         perms chown $clam_user:$clam_group "$clam_dbs/$db_file"
                                         chmod 0644 "$clam_dbs/$db_file"
@@ -468,7 +468,7 @@ while getopts 'bc:defg:himrs:tv' option ; do
                 echo "File '$input' cannot be found."
                 echo "Here is a list of third-party databases that can be clamscan integrity tested:"
                 echo ""
-                echo "Sanesecurity $ss_dbs""MSRBL $msrbl_dbs""SecuriteInfo $si_dbs""MalwarePatrol $mbl_dbs"
+                echo "Sanesecurity $ss_dbs""SecuriteInfo $si_dbs""MalwarePatrol $mbl_dbs"
                 echo "Check the file name and try again..."
           fi
           echo ""
@@ -575,7 +575,7 @@ if [ -n "$ham_dir" -a -d "$work_dir" -a ! -d "$test_dir" ] ; then
             grep -h -v -f "$config_dir/whitelist.hex" "$db_file" > "$db_file-tmp"
             mv -f "$db_file-tmp" "$db_file"
             if clamscan --quiet -d "$db_file" "$config_dir/scan-test.txt" 2>/dev/null ; then
-               if rsync -cqt $db_file $clam_dbs ; then
+               if rsync -pcqt $db_file $clam_dbs ; then
                   perms chown $clam_user:$clam_group $clam_dbs/$db_file
                   do_clamd_reload=1
                fi
@@ -600,7 +600,7 @@ fi
 
 # Check to see if the working directories have been created.
 # If not, create them.  Otherwise, ignore and proceed with script.
-mkdir -p "$work_dir" "$ss_dir" "$msrbl_dir" "$si_dir" "$mbl_dir" "$config_dir" "$gpg_dir" "$add_dir"
+mkdir -p "$work_dir" "$ss_dir" "$si_dir" "$mbl_dir" "$config_dir" "$gpg_dir" "$add_dir"
 
 # Set secured access permissions to the GPG directory
 chmod 0700 "$gpg_dir"
@@ -683,7 +683,6 @@ fi
 
 # Unofficial ClamAV database provider URLs
 ss_url="rsync.sanesecurity.net"
-msrbl_url="rsync.mirror.msrbl.com"
 si_url="clamav.securiteinfo.com"
 mbl_url="www.malwarepatrol.net"
 
@@ -697,15 +696,6 @@ if [ -n "$ss_dbs" ] ; then
    done
 fi
 
-# Create the MSRBL rsync "include" file (defines which files to download).
-msrbl_include_dbs="$config_dir/msrbl-include-dbs.txt"
-if [ -n "$msrbl_dbs" ] ; then
-   rm -f -- "$msrbl_include_dbs"
-   for db_name in $msrbl_dbs ; do
-      echo "$db_name" >> "$msrbl_include_dbs"
-   done
-fi
-
 # If rsync proxy is defined in the config file, then export it for use.
 if [ -n "$rsync_proxy" ]; then
    RSYNC_PROXY="$rsync_proxy"
@@ -741,7 +731,6 @@ fi
 if [ -n "$si_dbs" ] ; then
    for db in $si_dbs ; do
       echo "$si_dir/$db" >> "$current_tmp"
-      echo "$si_dir/$db.gz" >> "$current_tmp"
       clamav_files
    done
 fi
@@ -963,9 +952,9 @@ if [ -n "$ss_dbs" ] ; then
    comment "======================================================================"
    comment "Sanesecurity Database & GPG Signature File Updates"
    comment "======================================================================"
-   ss_mirror_ips=`dig +tcp +short $ss_url`
+   ss_mirror_ips=`dig +ignore +short $ss_url`
    for ss_mirror_ip in $ss_mirror_ips ; do
-      ss_mirror_name=`host $ss_mirror_ip | awk '{print $NF}' | cut -d "(" -f2 | sed 's/\(.*\)./\1/'`
+      ss_mirror_name=`dig +short -x $ss_mirror_ip | sed 's/\.$//'`
       ss_mirror_site_info="$ss_mirror_name $ss_mirror_ip"
       comment ""
       comment "Sanesecurity mirror site used: $ss_mirror_site_info"
@@ -1006,7 +995,7 @@ if [ -n "$ss_dbs" ] ; then
                                  log "WARNING - Clamscan reports Sanesecurity $db_file database integrity tested BAD - SKIPPING" ; false
                            fi && \
                            (test "$keep_db_backup" = "yes" && cp -f $clam_dbs/$db_file $clam_dbs/$db_file-bak 2>/dev/null ; true) && \
-                           if rsync -cqt $ss_dir/$db_file $clam_dbs
+                           if rsync -pcqt $ss_dir/$db_file $clam_dbs
                               then
                                  perms chown $clam_user:$clam_group $clam_dbs/$db_file
                                  comment "Successfully updated Sanesecurity production database file: $db_file"
@@ -1034,7 +1023,7 @@ if [ -n "$ss_dbs" ] ; then
                                  log "WARNING - Clamscan reports Sanesecurity $db_file database integrity tested BAD - SKIPPING" ; false
                            fi && \
                            (test "$keep_db_backup" = "yes" && cp -f $clam_dbs/$db_file $clam_dbs/$db_file-bak 2>/dev/null ; true) && \
-                           if rsync -cqt $test_dir/$db_file $clam_dbs
+                           if rsync -pcqt $test_dir/$db_file $clam_dbs
                               then
                                  perms chown $clam_user:$clam_group $clam_dbs/$db_file
                                  comment "Successfully updated Sanesecurity production database file: $db_file"
@@ -1072,115 +1061,12 @@ if [ -n "$ss_dbs" ] ; then
    fi
 fi
 
-#########################################
-# Check for MSRBL database file updates #
-#########################################
-if [ -n "$msrbl_dbs" ] ; then
-   db_file=""
-   comment ""
-   comment "======================================================================"
-   comment "MSRBL Database File Updates"
-   comment "======================================================================"
-   msrbl_mirror_ips=`dig +tcp +short $msrbl_url`
-   for msrbl_mirror_ip in $msrbl_mirror_ips ; do
-      msrbl_mirror_name=`host $msrbl_mirror_ip | awk '{print $NF}' | cut -d "(" -f2 | sed 's/\(.*\)./\1/'`
-      msrbl_mirror_site_info="$msrbl_mirror_name $msrbl_mirror_ip"
-      comment ""
-      comment "MSRBL mirror site used: $msrbl_mirror_site_info"
-      log "INFO - MSRBL mirror site used: $msrbl_mirror_site_info"
-      if rsync $rsync_output_level $no_motd --files-from=$msrbl_include_dbs -ctuz --stats \
-         $contimeout --timeout=30 rsync://$msrbl_mirror_ip/msrbl $msrbl_dir 2>/dev/null
-         then
-            msrbl_rsync_success="1"
-            for db_file in $msrbl_dbs ; do
-               if ! cmp -s $msrbl_dir/$db_file $clam_dbs/$db_file ; then
-                  comment ""
-                  comment "Testing updated MSRBL database file: $db_file"
-                  log "INFO - Testing updated MSRBL database file: $db_file"
-                  if [ "$?" = "0" ] ; then
-                     db_ext=`echo $db_file | cut -d "." -f2`
-                     if [ -z "$ham_dir" -o "$db_ext" != "ndb" ]
-                        then
-                           if clamscan --quiet -d "$msrbl_dir/$db_file" "$config_dir/scan-test.txt" 2>/dev/null
-                              then
-                                 comment "Clamscan reports Sanesecurity $db_file database integrity tested good"
-                                 log "INFO - Clamscan reports Sanesecurity $db_file database integrity tested good" ; true
-                              else
-                                 echo "Clamscan reports Sanesecurity $db_file database integrity tested BAD - SKIPPING"
-                                 log "WARNING - Clamscan reports Sanesecurity $db_file database integrity tested BAD - SKIPPING" ; false
-                           fi && \
-                           (test "$keep_db_backup" = "yes" && cp -f $clam_dbs/$db_file $clam_dbs/$db_file-bak 2>/dev/null ; true) && \
-                           if rsync -cqt $msrbl_dir/$db_file $clam_dbs
-                              then
-                                 perms chown $clam_user:$clam_group $clam_dbs/$db_file
-                                 comment "Successfully updated MSRBL production database file: $db_file"
-                                 log "INFO - Successfully updated MSRBL production database file: $db_file"
-                                 msrbl_update=1
-                                 do_clamd_reload=1
-                              else
-                                 echo "Failed to successfully update MSRBL production database file: $db_file - SKIPPING"
-                                 log "WARNING - Failed to successfully update MSRBL production database file: $db_file - SKIPPING"
-                           fi
-                        else
-                           grep -h -v -f "$config_dir/whitelist.hex" "$msrbl_dir/$db_file" > "$test_dir/$db_file"
-                           clamscan --infected --no-summary -d "$test_dir/$db_file" "$ham_dir"/* | \
-                           sed 's/\.UNOFFICIAL FOUND//' | awk '{print $NF}' > "$config_dir/whitelist.txt"
-                           grep -h -f "$config_dir/whitelist.txt" "$test_dir/$db_file" | \
-                           cut -d "*" -f2 | sort | uniq >> "$config_dir/whitelist.hex"
-                           grep -h -v -f "$config_dir/whitelist.hex" "$test_dir/$db_file" > "$test_dir/$db_file-tmp"
-                           mv -f "$test_dir/$db_file-tmp" "$test_dir/$db_file"
-                           if clamscan --quiet -d "$test_dir/$db_file" "$config_dir/scan-test.txt" 2>/dev/null
-                              then
-                                 comment "Clamscan reports Sanesecurity $db_file database integrity tested good"
-                                 log "INFO - Clamscan reports Sanesecurity $db_file database integrity tested good" ; true
-                              else
-                                 echo "Clamscan reports Sanesecurity $db_file database integrity tested BAD - SKIPPING"
-                                 log "WARNING - Clamscan reports Sanesecurity $db_file database integrity tested BAD - SKIPPING" ; false
-                           fi && \
-                           (test "$keep_db_backup" = "yes" && cp -f $clam_dbs/$db_file $clam_dbs/$db_file-bak 2>/dev/null ; true) && \
-                           if rsync -cqt $test_dir/$db_file $clam_dbs
-                              then
-                                 perms chown $clam_user:$clam_group $clam_dbs/$db_file
-                                 comment "Successfully updated MSRBL production database file: $db_file"
-                                 log "INFO - Successfully updated MSRBL production database file: $db_file"
-                                 msrbl_update=1
-                                 do_clamd_reload=1
-                              else
-                                 echo "Failed to successfully update MSRBL production database file: $db_file - SKIPPING"
-                                 log "WARNING - Failed to successfully update MSRBL production database file: $db_file - SKIPPING"
-                           fi
-                     fi
-                  fi
-               fi
-            done
-            if [ "$msrbl_update" != "1" ]
-               then
-                  comment ""
-                  comment "No MSRBL database file updates found"
-                  log "INFO - No MSRBL database file updates found"
-                  break
-               else
-                  break
-            fi
-         else
-            comment "Connection to $msrbl_mirror_site_info failed - Trying next mirror site..."
-            log "WARNING - Connection to $msrbl_mirror_site_info failed - Trying next mirror site..."
-      fi
-   done
-   if [ "$msrbl_rsync_success" != "1" ] ; then
-      echo ""
-      echo "Access to all MSRBL mirror sites failed - Check for connectivity issues or"
-      echo "signature database name(s) misspelled in the script's configuration file."
-      log "WARNING - Access to all MSRBL mirror sites failed - Check for connectivity issues or"
-      log "WARNING - signature database name(s) misspelled in the script's configuration file."
-   fi
-fi
-
 #######################################################################
 # Check for updated SecuriteInfo database files every set number of   #
 # hours as defined in the "USER CONFIGURATION" section of this script #
 #######################################################################
 if [ -n "$si_dbs" ] ; then
+   rm -f "$si_dir/*.gz"
    if [ -s "$config_dir/last-si-update.txt" ]
       then
          last_si_update=`cat $config_dir/last-si-update.txt`
@@ -1201,8 +1087,6 @@ if [ -n "$si_dbs" ] ; then
          log "INFO - Checking for SecuriteInfo updates..."
          si_updates="0"
          for db_file in $si_dbs ; do
-            z_opt="" DT1="" DT2=""
-            test -s $si_dir/$db_file.gz && DT1=`ls -l $si_dir/$db_file.gz | awk '{print $6,$7}'` && z_opt="-z $si_dir/$db_file.gz"
             if [ "$loop" = "1" ]
                then
                   comment "---"
@@ -1212,18 +1096,22 @@ if [ -n "$si_dbs" ] ; then
             comment "Checking for updated SecuriteInfo database file: $db_file"
             comment ""
             si_db_update="0"
+            if [ -s "$si_dir/$db_file" ]
+               then
+                  z_opt="-z $si_dir/$db_file"
+               else
+                  z_opt=""
+            fi
             if curl $curl_proxy $curl_output_level --connect-timeout 15 --max-time 60 \
-               -L -R $z_opt -o $si_dir/$db_file.gz http://$si_url/$db_file.gz
+               -L -R $z_opt -o $si_dir/$db_file http://$si_url/$db_file
                then
                   loop="1"
-                  test -s $si_dir/$db_file.gz && DT2=`ls -l $si_dir/$db_file.gz | awk '{print $6,$7}'` && \
-                  test "$DT1" != "$DT2" -o ! -s "$si_dir/$db_file" && gunzip -cdfq $si_dir/$db_file.gz > $si_dir/$db_file
                   if ! cmp -s $si_dir/$db_file $clam_dbs/$db_file ; then
-                     comment ""
-                     comment "Testing updated SecuriteInfo database file: $db_file"
-                     log "INFO - Testing updated SecuriteInfo database file: $db_file"
                      if [ "$?" = "0" ] ; then
                         db_ext=`echo $db_file | cut -d "." -f2`
+			comment ""
+                        comment "Testing updated SecuriteInfo database file: $db_file"
+                        log "INFO - Testing updated SecuriteInfo database file: $db_file"
                         if [ -z "$ham_dir" -o "$db_ext" != "ndb" ]
                            then
                               if clamscan --quiet -d "$si_dir/$db_file" "$config_dir/scan-test.txt" 2>/dev/null
@@ -1233,9 +1121,10 @@ if [ -n "$si_dbs" ] ; then
                                  else
                                     echo "Clamscan reports Sanesecurity $db_file database integrity tested BAD - SKIPPING"
                                     log "WARNING - Clamscan reports Sanesecurity $db_file database integrity tested BAD - SKIPPING" ; false
+                                    rm -f "$si_dir/$db_file"
                               fi && \
                               (test "$keep_db_backup" = "yes" && cp -f $clam_dbs/$db_file $clam_dbs/$db_file-bak 2>/dev/null ; true) && \
-                              if rsync -cqt $si_dir/$db_file $clam_dbs
+                              if rsync -pcqt $si_dir/$db_file $clam_dbs
                                  then
                                     perms chown $clam_user:$clam_group $clam_dbs/$db_file
                                     comment "Successfully updated SecuriteInfo production database file: $db_file"
@@ -1262,9 +1151,10 @@ if [ -n "$si_dbs" ] ; then
                                  else
                                     echo "Clamscan reports Sanesecurity $db_file database integrity tested BAD - SKIPPING"
                                     log "WARNING - Clamscan reports Sanesecurity $db_file database integrity tested BAD - SKIPPING" ; false
+                                    rm -f "$si_dir/$db_file"
                               fi && \
                               (test "$keep_db_backup" = "yes" && cp -f $clam_dbs/$db_file $clam_dbs/$db_file-bak 2>/dev/null ; true) && \
-                              if rsync -cqt $test_dir/$db_file $clam_dbs
+                              if rsync -pcqt $test_dir/$db_file $clam_dbs
                                  then
                                     perms chown $clam_user:$clam_group $clam_dbs/$db_file
                                     comment "Successfully updated SecuriteInfo production database file: $db_file"
@@ -1340,11 +1230,11 @@ if [ -n "$mbl_dbs" ] ; then
                then
                   if ! cmp -s $mbl_dir/$db_file $clam_dbs/$db_file 
                      then
-                        comment ""
-                        comment "Testing updated MalwarePatrol database file: $db_file"
-                        log "INFO - Testing updated database file: $db_file"
                         if [ "$?" = "0" ] ; then
                            db_ext=`echo $db_file | cut -d "." -f2`
+                           comment ""
+                           comment "Testing updated MalwarePatrol database file: $db_file"
+                           log "INFO - Testing updated database file: $db_file"
                            if [ -z "$ham_dir" -o "$db_ext" != "ndb" ]
                               then
                                  if clamscan --quiet -d "$mbl_dir/$db_file" "$config_dir/scan-test.txt" 2>/dev/null
@@ -1356,7 +1246,7 @@ if [ -n "$mbl_dbs" ] ; then
                                        log "WARNING - Clamscan reports Sanesecurity $db_file database integrity tested BAD - SKIPPING" ; false
                                  fi && \
                                  (test "$keep_db_backup" = "yes" && cp -f $clam_dbs/$db_file $clam_dbs/$db_file-bak 2>/dev/null ; true) && \
-                                 if rsync -cqt $mbl_dir/$db_file $clam_dbs
+                                 if rsync -pcqt $mbl_dir/$db_file $clam_dbs
                                     then
                                        perms chown $clam_user:$clam_group $clam_dbs/$db_file
                                        comment "Successfully updated MalwarePatrol production database file: $db_file"
@@ -1384,7 +1274,7 @@ if [ -n "$mbl_dbs" ] ; then
                                        log "WARNING - Clamscan reports Sanesecurity $db_file database integrity tested BAD - SKIPPING" ; false
                                  fi && \
                                  (test "$keep_db_backup" = "yes" && cp -f $clam_dbs/$db_file $clam_dbs/$db_file-bak 2>/dev/null ; true) && \
-                                 if rsync -cqt $test_dir/$db_file $clam_dbs
+                                 if rsync -pcqt $test_dir/$db_file $clam_dbs
                                     then
                                        perms chown $clam_user:$clam_group $clam_dbs/$db_file
                                        comment "Successfully updated MalwarePatrol production database file: $db_file"
@@ -1438,7 +1328,7 @@ if [ -n "$add_dbs" ] ; then
       db_file=`basename $db_url`
       if [ "`echo $db_url | cut -d ":" -f1`" = "rsync" ]
          then
-            if ! rsync $rsync_output_level $no_motd $contimeout --timeout=30 -ctuz --exclude=*.txt \
+            if ! rsync $rsync_output_level $no_motd $contimeout --timeout=30 -crtuz --exclude=*.txt \
                  --stats --exclude=*.sha256 --exclude=*.sig --exclude=*.gz $db_url $add_dir ; then
                echo "Failed rsync connection to $base_url - SKIPPED $db_file update"
                log "WARNING - Failed rsync connection to $base_url - SKIPPED $db_file update"
@@ -1469,7 +1359,7 @@ if [ -n "$add_dbs" ] ; then
                log "WARNING - Clamscan reports $db_file database integrity tested BAD - SKIPPING" ; false
          fi && \
          (test "$keep_db_backup" = "yes" && cp -f $clam_dbs/$db_file $clam_dbs/$db_file-bak 2>/dev/null ; true) && \
-         if rsync -cqt $add_dir/$db_file $clam_dbs
+         if rsync -pcqt $add_dir/$db_file $clam_dbs
             then
                perms chown $clam_user:$clam_group $clam_dbs/$db_file
                comment "Successfully updated User-Added production database file: $db_file"
@@ -1531,7 +1421,7 @@ if [ -s "$clam_dbs/local.ign" -a -s "$config_dir/monitor-ign.txt" ] ; then
    if [ "$ign_updated" = "1" ] ; then
       if clamscan --quiet -d "$config_dir/local.ign" "$config_dir/scan-test.txt"
          then
-            if rsync -cqt $config_dir/local.ign $clam_dbs
+            if rsync -pcqt $config_dir/local.ign $clam_dbs
                then
                   perms chown $clam_user:$clam_group "$clam_dbs/local.ign"
                   chmod 0644 "$clam_dbs/local.ign" "$config_dir/monitor-ign.txt"
